"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var Validation = /** @class */ (function () {
    // ########################################
    function Validation(rootPath, allowedProtocolVersions, ajv) {
        this.rootPath = rootPath;
        this.allowedProtocolVersions = allowedProtocolVersions;
        this.ajv = ajv;
        // ########################################
        this.errors = [];
    }
    // ########################################
    Validation.prototype.isValid = function (rulesetPath) {
        var _this = this;
        var path = fs.realpathSync(rulesetPath);
        if (!fs.existsSync(path)) {
            this.addErrorMessage("Ruleset " + path + " does not exist");
            return false;
        }
        var rulesJsonBuffer = fs.readFileSync(path);
        var rulesJsonData = JSON.parse(rulesJsonBuffer);
        var protocolVersion = String(rulesJsonData.protocol_version);
        if (!this.allowedProtocolVersions.includes(protocolVersion)) {
            this.addErrorMessage("protocol-version: " + protocolVersion + " not support in this engine version.");
            return false;
        }
        var jsonSchema = fs.readFileSync(this.rootPath + "/../ruleset-schema.json");
        var jsonSchemaData = JSON.parse(jsonSchema);
        if (!this.ajv.validate(jsonSchemaData, rulesJsonData)) {
            var ajvErrors = this.ajv.errors;
            if (ajvErrors) {
                ajvErrors.forEach(function (error) {
                    _this.addErrorMessage(error.message);
                });
            }
        }
        if (this.errors.length === 0) {
            return true;
        }
        return false;
    };
    // ########################################
    Validation.prototype.getErrorsMessages = function () {
        return this.errors;
    };
    // ########################################
    Validation.prototype.addErrorMessage = function (error) {
        this.errors.push(error);
    };
    return Validation;
}());
exports.Validation = Validation;
